import React from "react";
import PropTypes from "prop-types";
import { withStyles } from "@material-ui/core/styles";
import Card from "@material-ui/core/Card";
import CardActions from "@material-ui/core/CardActions";
import CardContent from "@material-ui/core/CardContent";
import Button from "@material-ui/core/Button";
import Typography from "@material-ui/core/Typography";
import { Divider } from "@material-ui/core";
import ExpansionPanel from "@material-ui/core/ExpansionPanel";
import ExpansionPanelSummary from "@material-ui/core/ExpansionPanelSummary";
import ExpansionPanelDetails from "@material-ui/core/ExpansionPanelDetails";
import ExpandMoreIcon from "@material-ui/icons/ExpandMore";
import Rhino from "./Exercise03/Rhino";
import Openscad from "./Exercise03/Openscad";
import Inkscape from "./Exercise03/Inkscape";
import Gimp from "./Exercise03/Gimp";
import Solidworks from "./Exercise03/Solidworks";

const styles = theme => ({
  card: {
    minWidth: 275
  },
  bullet: {
    display: "inline-block",
    margin: "0 2px",
    transform: "scale(0.8)"
  },
  title: {
    fontSize: 14
  },
  pos: {
    marginBottom: 12
  },
  root: {
    width: "100%"
  },
  heading: {
    fontSize: theme.typography.pxToRem(15),
    fontWeight: theme.typography.fontWeightRegular
  }
});

function SimpleCard(props) {
  const { classes } = props;

  return (
    <div>
      <Card className={classes.card}>
        <CardContent>
          <Typography
            className={classes.title}
            color="textSecondary"
            gutterBottom
          >
            Jan 30, 2019
          </Typography>
          <Typography variant="h5" component="h2">
            Computer-Aided Design
          </Typography>
          <Typography className={classes.pos} color="textSecondary">
            (2D, 2.5D, 3D) design
          </Typography>
          <Typography component="p">
            assignment:
            <br />
            {
              '"model (raster, vector, 2D, 3D, render, animate, simulate, ...) a possible final project, and post it on your class page "'
            }
          </Typography>
        </CardContent>
        <CardActions>
          <Button
            href="http://academy.cba.mit.edu/classes/computer_design/index.html"
            target="_blank"
            size="small"
          >
            Learn More
          </Button>
        </CardActions>
        <Divider />
      </Card>
      <br />
      <div className={classes.root}>
        <ExpansionPanel>
          <ExpansionPanelSummary expandIcon={<ExpandMoreIcon />}>
            <Typography className={classes.heading}>3D design</Typography>
          </ExpansionPanelSummary>
          <ExpansionPanelDetails>
            <Rhino />
          </ExpansionPanelDetails>
          <ExpansionPanelDetails>
            <Openscad />
          </ExpansionPanelDetails>
          <ExpansionPanelDetails>
            <Solidworks />
          </ExpansionPanelDetails>
        </ExpansionPanel>
        <ExpansionPanel>
          <ExpansionPanelSummary expandIcon={<ExpandMoreIcon />}>
            <Typography className={classes.heading}>
              2D, 2.5D design - raster
            </Typography>
          </ExpansionPanelSummary>
          <ExpansionPanelDetails>
            <Gimp />
          </ExpansionPanelDetails>
        </ExpansionPanel>
        <ExpansionPanel>
          <ExpansionPanelSummary expandIcon={<ExpandMoreIcon />}>
            <Typography className={classes.heading}>
              2D, 2.5D design - vector
            </Typography>
          </ExpansionPanelSummary>
          <ExpansionPanelDetails>
            <Inkscape />
          </ExpansionPanelDetails>
        </ExpansionPanel>
      </div>
    </div>
  );
}

SimpleCard.propTypes = {
  classes: PropTypes.object.isRequired
};

export default withStyles(styles)(SimpleCard);
