Electronic design automation (EDA) is a term for a category of software products and processes that help to design electronic systems with the aid of computers. These tools are often used to design circuit boards, processors and other types of complex electronics.

# Autodesk EAGLE

Autodesk EAGLE is an electronic design automation (EDA) software. It enables PCB designers to seamlessly connect schematic diagrams, component placement, PCB routing, and comprehensive library content.

I watched few AutoDesk Webinars and tried tutorials first. Once I got enough info, I began to make hello echo board.
I've described what I learned about the Eagle software below.
## EAGLE control panel:

- The assets tree available in EAGLE control panel has _Libraries_, _Design Blocks_, _Design Rules_, _User Language Programs_, _Scripts_, _CAM Jobs_, _SPICE Models_ and _Projects_.
- Every asset has two directories.
  - Managed: Can't be modified by user.
  - User Defined.
- _Libraries_ : It contains circuit components.
- _Design Blocks_ : Schematic and board pieces of circuits that can be reused.
- _Design Rules_ : It is set up to match whatever the board house can do so that way if it flags an error it's the same error that the board house would flag. Some board houses provide the design rules in EAGLE format.
- _User Language Programs_ : This is folder for EAGLE scripts. EAGLE scripts are written in C, C++ type programming language. ULPs are mostly used for import/exports and custom functionalities like commands and shortcuts.
- _Scripts_ : Scripts are related to UPLs. These are EAGLE commands in a file, one right after the other. The EAGLE goes line by line through these commands. UPLs can't do things by themselves because they only have read-only access. UPLs use scripts to perform operations.
  - eagle.SRC file: This is a configuration script. Any default setup like layers, grids, commands goes into it.

```
    # Configuration Script
    #
    # This file can be used to configure the editor windows.
    #
    # Uncomment this if you want a set of useful default shortcuts!
    #SCRIPT default-assign.scr;
    #

    BRD:
    MENU '[bin/designlink.svg] Search and order : Run designlink-order.ulp -general;'\
         '[bin/pcb-service.svg] PCB Service : Run pcb-service.ulp;'\
    ;
    DISPLAY = 'Preset_Top' None 1 17 18 19 20 21 23 25 39 41 51;
    DISPLAY = 'Preset_Bottom' None 16 17 18 19 20 22 24 26 40 42 52;
    DISPLAY = 'Preset_Standard' None 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 39 40 41 42 51 52;

    SCH:
    Grid Default;
    Change Width 0.006in;
    MENU '[bin/designlink.svg] Search and order {\
                                              General : Run designlink-order.ulp -general; |\
                                              Schematic : Run designlink-order.ulp; \
                                              }'\
    ;

    LBR:
    MENU '[bin/designlink.svg] Search and order : Run designlink-order.ulp -general;'\
         '[bin/pads-pcb.svg] PADS package import : RUN import-pads-powerpcb-v5;' \
    ;

    DEV:
    Grid Default;
    MENU '[bin/designlink.svg] Search and order : Run designlink-order.ulp -general;' \
         '[bin/pads-pcb.svg] PADS package import : RUN import-pads-powerpcb-v5;'\
    ;

    SYM:
    Grid Default On;
    Change Width 0.010in;

    PAC:
    Grid Default On;
    Change Width 0.005in;
    Change Size 0.050in;
    MENU '[bin/pads-pcb.svg] PADS package import : RUN import-pads-powerpcb-v5;' \
         ;
```

- _CAM Jobs_ : Generates manufacturing data. Can be used to export dxf files.
- _SPICE Models_ : ngspice is the open source spice simulator for electric and electronic circuits.
- _Projects_ : Here projects are stored. (Recommended by EAGLE.)

## General steps for PCB Design with EAGLE

### Step-1: Schematic Design

1. Create new project: User Projects -> Right Click -> New Project
2. Add schematic (.sch) file to project : ProjectName -> right-click ->New
3. Enter command **add** or choose 'Add part' from left side tool bar. This opens a window titled 'add' with all the schematic components.
4. The search bar can be used to search for specific part. It isn't like a regular Internet search engine. Search query needs to be exact or wild card like '*','? ' can be used to find the components. - Tip: The search is case sensitive. *R0805* is not same as *ro805\*. - Tip: The components can be copy pasted. No need to browse the library for existing components on schematic. - Tip: The 'add part' in toolbar has **history** feature. Just right click on it to use previously used components.

   - Tip: Any icon on toolbar that has \*down-arrow\* supports history and it can be accessed by right-click.

   <p align="center">
       ![Add Part History][history] 
   </p>
   [history]: /2019/labs/vigyanashram/students/manoj-sahukar/eagle/Screenshot_1.png "Add Part History"

5. It is good to define a work area by adding a frame first. Search frame to find. Frames are available in two varieties. Landscape and Portrait. For small circuits it is okay to choose Letter size. Snap it to origin to place.
   - Tip: The add command stays active even after adding a component to schematic. We can just press escape to switch to 'add' window again. We can repeat this until we add all the components to the schematic.
   - Tip: Every symbol has origin marked as **+** sign. Left click and drag works only when we click on the origin.
   - Tip: Use right-click shortcut to rotate the component while placing on schematic.
6. **net** command is used for making connections. (Maintain a grid size of 0.1 inch.)
   - Don't use **line** or **wire** commands for connections as recommended by Eagle.
7. Supply symbols are special in Eagle. Even if they are not connected they are internally all connected one main. Each net segment has its own naming. The Supply components also have their own net segment name. When connecting to existing segment merging is required.

   <p align="center">
       ![Merge net segment][merge] 
   </p>
   [merge]: /2019/labs/vigyanashram/students/manoj-sahukar/eagle/Screenshot_2.png "Merge net segment"

8. Next we assign value by using **value** command.

### Step-2: Board Design

1. To switch to board click on the icon as shown below. The board design window also has an icon for switching to schematic.

<p align="center">
    ![Switch to Board][Switch_b] ![Switch to Schematic][Switch_s] 
</p>
[Switch_b]: /2019/labs/vigyanashram/students/manoj-sahukar/eagle/Screenshot_3.png "Switch to Board"
[Switch_s]: /2019/labs/vigyanashram/students/manoj-sahukar/eagle/Screenshot_4.png "Switch to Schematic"

2. The group command is always active if nothing else is. It is used to group and drag all the parts to the outline area. The group is dragged to outline area by left-click drag.
   - With active left-click, simultaneous
     - right-clicking makes the part group rotate.
     - middle-click on mouse makes the part group mirror itself.
3. The outline can be resized by dragging on the edges with left-click.
4. The individual components can be placed by dragging with left-click. There is align tool to place components in an orderly fashion.
5. It time for rat's nest. _Rat's nest_ is an English idiom meaning "a place of great clutter or disorder.In EAGLE there is a tool called **ratsnest** to removes all multisegment airwires and replaces them with one straight airwire.
   - Airwires : Electrical connections between pads often intersecting each other.
6. Routing Tools:
   - Polygon: The polygon tool can be used for setting up common ground. Once polygon closes it asks for 'name' input. Using 'GND' as polygon name, all grounds can be made to connect. Using **Ratsnest** command, after constructing polygon should create a common route base connecting all the GNDs.
   - Rip Up: It converts routes to Airwire. This can be used to rip up Route overlay created by (polygon + ratsnest).
   - Assisted Routing:
     - Quick Route Airwire: Converts airwire into route.
     - Quick Route Signal: Converts
     - Quick Route Multiple Airwire:
     - Smooth Signal:
   - Tip: Hit **Backspace** during routing to undo partially, only the last segment.

## Assignment - Redraw Hello Echo board

1. Added [Fab Library](https://github.com/Academany/FabAcademany-Resources/blob/master/files/fab.lbr) to Eagle by downloading and moving the **fab.lbr** file to _C:\Users\Manoj Sahukar\Documents\EAGLE\libraries_. Now this library is available under _Libraries_ tree in control panel.
   - To use this library we need to tell Eagle explicitly. Right-clicking on fab.lbr file and ticking the _Use_ check box.
2. Created a new project under _Projects_ tree named 'hello'.
3. Added schematic by right-click on _hello_ > New > Schematic.

<p align="center">
![Schematic][Schematic]
</p>
[Schematic]: /2019/labs/vigyanashram/students/manoj-sahukar/eagle/schematic.png "Schematic"

4. Routing

<p align="center">
    ![Board][board_all_layers] ![Board Trace][board_trace]
</p>
[board_all_layers]: /2019/labs/vigyanashram/students/manoj-sahukar/eagle/board.png "Board"
[board_trace]: /2019/labs/vigyanashram/students/manoj-sahukar/eagle/board_trace.png "Board trace"

**Defective outline file** as it seems the png file needs to be transparent on the areas outside the outline. I was not doing a rectangular outline like I used to do previously. Fortunately, I was able notice the during milling and stopped the job without any damage.

<p align="center">
    ![Board outline][board_outline] 
</p>

[board_outline]: /2019/labs/vigyanashram/students/manoj-sahukar/eagle/board_outline.png "Board outline"

## Milling

<p align="center">
![rml_tarce][rml_tarce]
</p>
[rml_tarce]: /2019/labs/vigyanashram/students/manoj-sahukar/eagle/rml_tarce.png "rml_tarce"

**Defective RML file** as the outline file used for the patch generation is defective png. I will test an outline file with **not rectangular outline** with transparent area outside outline to verify.

<p align="center">
![rml_outline][rml_outline]
</p>
[rml_outline]: /2019/labs/vigyanashram/students/manoj-sahukar/eagle/rml_outline.png "rml_outline"

PCB under background light for checking shorts.

<p align="center">
![pcb.jpeg][pcb.jpeg]
</p>
[pcb.jpeg]: /2019/labs/vigyanashram/students/manoj-sahukar/eagle/pcb.jpeg "pcb.jpeg"

## Calculate Resistor Value

As given in the [data sheet](https://github.com/Academany/FabAcademany-Resources/blob/master/files/fab.lbr), the _DC Forward current_ for the this LED is 40 mA. and _Peak forward current_ is 200 mA. Hence, For a 5 volt supply the resister needed for limiting current is in the range of 25 ohm to 125 ohm. I have used 100 ohm resister in my circuit accordingly.

<p align="center">
![LED][LED]
</p>
[LED]: /2019/labs/vigyanashram/students/manoj-sahukar/eagle/LED.png "LED Data sheet"

## Assembly

<p align="center">
![assem_board.jpg][assem_board.jpg]
</p>
[assem_board.jpg]: /2019/labs/vigyanashram/students/manoj-sahukar/eagle/assem_board.jpg "assem_board.jpg"

# Programming board with **echo hello-world** !

<p align="center">
![Hello Echo program][files]
</p>
[files]: /2019/labs/vigyanashram/students/manoj-sahukar/eagle/files.png "files need for prog"

The make command didn't work from windows command prompt this time. I use windows command prompt mostly even for git.

<p align="center">
![windows-make][windows-make]
</p>
[windows-make]: /2019/labs/vigyanashram/students/manoj-sahukar/eagle/windows-make.png "windows-make"

However, make command worked in **git-bash**. I don't know yet why.

<p align="center">
![make command][make]
</p>
[make]: /2019/labs/vigyanashram/students/manoj-sahukar/eagle/make.png "make command"

My board includes a reset button. This can reset the echo keystrokes stored in board. This I've shown in the screenshot below.

<p align="center">
![Hello Echo program][echo_mango]
</p>
[echo_mango]: /2019/labs/vigyanashram/students/manoj-sahukar/eagle/echo_mango.png "echo_mango"

# KiCAD

Pending
