# Arduino As ISP

When I used 'PB2' this didn't set PB2 port as output. Instead 'PA2' was set as output. It seems the Arduino by default use PA pins only.

I think, It is not meant to be use this way. It seems the values in PB2, PA2 etc are defined in imported avr library which represent number that we need to shift using DDRB or DDRA utility.

```C
// the setup function runs once when you press reset or power the board
void setup() {
  // initialize digital pin LED_BUILTIN as an output.
  pinMode(PB2, OUTPUT);
}

// the loop function runs over and over again forever
void loop() {
  digitalWrite(PB2, HIGH);   // turn the LED on (HIGH is the voltage level)
  delay(5000);                       // wait for a second
  digitalWrite(PB2, LOW);    // turn the LED off by making the voltage LOW
  delay(5000);                       // wait for a second
 PB2
```

## Push Button as input program

```C
int state =LOW;
void setup() {
  // put your setup code here, to run once:
  pinMode(PA2, OUTPUT);
  digitalWrite(PA2, HIGH);

  pinMode(PA7, INPUT_PULLUP);
//  pinMode(PA7, INPUT);
//  digitalWrite(PA7, HIGH);
}

void loop() {
  // put your main code here, to run repeatedly:
  state = digitalRead(PA7);
  if (state == HIGH){
    digitalWrite(PA2, HIGH);
  }
  else {
    digitalWrite(PA2, LOW);
    }
}
```

## Push Button input latch program

```C
int state = HIGH;
int latch = HIGH;
int prev = HIGH;

void setup() {
  pinMode(PA2, OUTPUT);
  pinMode(PA7, INPUT_PULLUP); //Pin PA7 is HIGH internally
}

void loop() {
  prev = state;
  state = digitalRead(PA7);

  if (prev !=LOW){ // taking care of continuous press of button
  if (state == LOW){
    latch = !latch;
    delay(300); // without delay the program didn't work properly.
  }
}
   digitalWrite(PA2, latch);
}
```

# Embedded C Program

## Blink One LED

```C
#include <avr/io.h>
#include <util/delay.h>

int main(void)
{
  // inits
  DDRB |= (1 << PB2);   // set data direction register for PB2 as output

  // event loop
  while (1)
 {
    PORTB |= (1 << PB2);   // turn on led
    _delay_ms(250);      // delay 250 ms

    PORTB = 0;  // turn off led
    //PORTB &= ~(1 << PB2);  // turn off led
    _delay_ms(250);      // delay 250 ms
  }
  return (0);
}
```

## Blink Two LED

<p align="center">
![twoled][twoled]
[twoled]: /2019/labs/vigyanashram/students/manoj-sahukar/week09/twoled.jpg ""
</p>

```C
#include <avr/io.h>
#include <util/delay.h>

int main(void)
{
  // inits
//  DDRA |= (1 << PA3);
//  DDRA |= (1 << PA2);
  DDRA = 0b11111111;

  // event loop
  while (1)
 {
    PORTA = 0b11111111 ;   // turn on all led
    _delay_ms(250);      // delay 250 ms

    PORTA = 0; // turn off all led
//    PORTA &= ~(1 << PA2);  // turn off led
//    PORTA &= ~(1 << PA3);   // turn off led
    _delay_ms(250);      // delay 250 ms
  }
  return (0);
}
```

## Blink One LED with one LED ON

```C
#include <avr/io.h>
#include <util/delay.h>

int main(void)
{
  // inits
  DDRA |= (1 << PA3);
  DDRA |= (1 << PA2);
  PORTA |= (1 << PA2);   // turn on led selectively
  //PORTA |= 0b11111111; // turn on all LED on port A
  // event loop
  while (1)
 {
    PORTA |= (1 << PA3);   // turn on led selectively
    _delay_ms(250);      // delay 250 ms

   PORTA &= ~(1 << PA3);  // turn off led selectively
    _delay_ms(250);      // delay 250 ms
  }
  return (0);
}

```

## Read from Ultrasonic Sensor - PING Arduino

<p align="center">
![ultra][ultra]
[ultra]: /2019/labs/vigyanashram/students/manoj-sahukar/week09/ultra.jpg ""
</p>

```C
/*
  Ping))) Sensor

  This sketch reads a PING))) ultrasonic rangefinder and returns the distance
  to the closest object in range. To do this, it sends a pulse to the sensor to
  initiate a reading, then listens for a pulse to return. The length of the
  returning pulse is proportional to the distance of the object from the sensor.

  The circuit:
	- +V connection of the PING))) attached to +5V
	- GND connection of the PING))) attached to ground
	- SIG connection of the PING))) attached to digital pin 7

  created 3 Nov 2008
  by David A. Mellis
  modified 30 Aug 2011
  by Tom Igoe

  This example code is in the public domain.

  http://www.arduino.cc/en/Tutorial/Ping

  Modified my Manoj Sahukar to use it on Attiny44. 19/03/19
*/
#include <SoftwareSerial.h>

SoftwareSerial mySerial(PA1, PA0); // RX, TX

// this constant won't change. It's the pin number of the sensor's output:
const int pingPin = PA2;

void setup() {
  // initialize mySerial communication:
  mySerial.begin(9600);
}

void loop() {
  // establish variables for duration of the ping, and the distance result
  // in inches and centimeters:
  long duration, inches, cm;

  // The PING))) is triggered by a HIGH pulse of 2 or more microseconds.
  // Give a short LOW pulse beforehand to ensure a clean HIGH pulse:
  pinMode(pingPin, OUTPUT);
  digitalWrite(pingPin, LOW);
  delayMicroseconds(2);
  digitalWrite(pingPin, HIGH);
  delayMicroseconds(5);
  digitalWrite(pingPin, LOW);

  // The same pin is used to read the signal from the PING))): a HIGH pulse
  // whose duration is the time (in microseconds) from the sending of the ping
  // to the reception of its echo off of an object.
  pinMode(pingPin, INPUT);
  duration = pulseIn(pingPin, HIGH);

  // convert the time into a distance
  inches = microsecondsToInches(duration);
  cm = microsecondsToCentimeters(duration);

  mySerial.print(inches);
  mySerial.print("in, ");
  mySerial.print(cm);
  mySerial.print("cm");
  mySerial.println();

  delay(100);
}

long microsecondsToInches(long microseconds) {
  // According to Parallax's datasheet for the PING))), there are 73.746
  // microseconds per inch (i.e. sound travels at 1130 feet per second).
  // This gives the distance travelled by the ping, outbound and return,
  // so we divide by 2 to get the distance of the obstacle.
  // See: http://www.parallax.com/dl/docs/prod/acc/28015-PING-v1.3.pdf
  return microseconds / 74 / 2;
}

long microsecondsToCentimeters(long microseconds) {
  // The speed of sound is 340 m/s or 29 microseconds per centimeter.
  // The ping travels out and back, so to find the distance of the object we
  // take half of the distance travelled.
  return microseconds / 29 / 2;
}
```
