# Concept

We're making a model of **Cable Driven Robot** meant for agricultural automation. This is inspired by Farmbot and Spidercam.

<ReactPlayer url='https://www.youtube.com/watch?v=8r0CiLBM1o8' controls/>
<br />
<ReactPlayer url='https://youtu.be/wor4BFjbIyI' controls/>

# Control System

I wanted to making my version of [Distributed Dataflow Machine Controllers](https://gitlab.cba.mit.edu/squidworks/squidworks). My plan is to make 'A4988 driver along with attiny44 MCU' as I2C slave boards, an Arduino as Master board running **Standard Firmata**. The master will be controlled by [pyFirmata](https://pypi.org/project/pyFirmata/) Python.

## Stepper Motor

<ReactPlayer url='https://youtu.be/B02lvFn6yXc' controls/>

```C
/* Simple Stepper Motor Control Example Code
 *
 *  by Dejan Nedelkovski, www.HowToMechatronics.com
 *
 */
/* Modified by Manoj Sahukar */

const int stepPin = 3;
const int dirPin = 4;
const int dly = 1000; //Minimum value for motor is 1000us

void setup() {
// Sets the two pins as Outputs
pinMode(stepPin,OUTPUT);
pinMode(dirPin,OUTPUT);
}
void loop() {
digitalWrite(dirPin,HIGH); // Enables the motor to move in a particular direction
// Makes 200 pulses for making one full cycle rotation
for(int x = 0; x < 200; x++) {
digitalWrite(stepPin,HIGH);
delayMicroseconds(dly);
digitalWrite(stepPin,LOW);
delayMicroseconds(dly);
}
delay(1000); // One second delay

digitalWrite(dirPin,LOW); //Changes the rotations direction
// Makes 400 pulses for making two full cycle rotation
for(int x = 0; x < 400; x++) {
digitalWrite(stepPin,HIGH);
delayMicroseconds(dly);
digitalWrite(stepPin,LOW);
delayMicroseconds(dly);
}
delay(1000);
}

```

## I2C Slave

<ReactPlayer url='https://youtu.be/PkgQzp5ex-8' controls/>

```C
#include <Wire.h>

void setup() {
 Wire.begin(2);                /* join i2c bus with address 1 */
 Wire.onReceive(receiveEvent); /* register receive event */
 Wire.onRequest(requestEvent); /* register request event */
 Serial.begin(9600);           /* start serial for debug */
}

void loop() {
 delay(100);
}

// function that executes whenever data is received from master
void receiveEvent(int howMany) {
 while (0 <Wire.available()) {
    char c = Wire.read();      /* receive byte as a character */
    Serial.print(c);           /* print the character */
  }
 Serial.println();             /* to newline */
}

// function that executes whenever data is requested from master
void requestEvent() {
 Wire.write("Hello NodeMCU");  /*send string on request */
}
```

## I2C Scanner

[I2C Scanner](https://playground.arduino.cc/Main/I2cScanner/) was used to find I2C addresses of slaves.

```C
#include <Wire.h>

void setup()
{
  Wire.begin();

  Serial.begin(9600);
  while (!Serial);             // Leonardo: wait for serial monitor
  Serial.println("\nI2C Scanner");
}


void loop()
{
  byte error, address;
  int nDevices;

  Serial.println("Scanning...");

  nDevices = 0;
  for(address = 1; address < 127; address++ )
  {
    // The i2c_scanner uses the return value of
    // the Write.endTransmisstion to see if
    // a device did acknowledge to the address.
    Wire.beginTransmission(address);
    error = Wire.endTransmission();

    if (error == 0)
    {
      Serial.print("I2C device found at address 0x");
      if (address<16)
        Serial.print("0");
      Serial.print(address,HEX);
      Serial.println("  !");

      nDevices++;
    }
    else if (error==4)
    {
      Serial.print("Unknown error at address 0x");
      if (address<16)
        Serial.print("0");
      Serial.println(address,HEX);
    }
  }
  if (nDevices == 0)
    Serial.println("No I2C devices found\n");
  else
    Serial.println("done\n");

  delay(5000);           // wait 5 seconds for next scan
}
```
